# About arimafd


Arimafd is a Python package that provides algorithms
for online prediction and anomaly detection. One of the
applications of this package can be the early detection
of faults in technical systems.



# Main Features


- Differentiation and integration of series including seasonal components
- Finding best hyperparametrs for ARIMA model
- Online forecasting based on ARIMA model
- Anomaly detection 
- Evaluating score of anomaly detection algorithms

# How to get it
The master branch on GitHub 

https://github.com/waico/arimafd


Binaries and source distributions are available from PyPi

https://pypi.org/project/arimafd/



# License

MIT
